@@ -1,23 +1,9 @@
 /*
  * BluezQt - Asynchronous BlueZ wrapper library
  *
- * Copyright (C) 2019 Kai Uwe Broulik <kde@broulik.de>
+ * SPDX-FileCopyrightText: 2019 Kai Uwe Broulik <kde@broulik.de>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef BLUEZQT_BATTERY_H
@@ -25,12 +11,13 @@
 
 #include <QObject>
 
-#include "types.h"
 #include "bluezqt_export.h"
+#include "types.h"
+
+#include <memory>
 
 namespace BluezQt
 {
-
 /**
  * @class BluezQt::Battery battery.h <BluezQt/Battery>
  *
@@ -47,7 +34,7 @@ public:
     /**
      * Destroys a Battery object.
      */
-    ~Battery();
+    ~Battery() override;
 
     /**
      * Returns a shared pointer from this.
@@ -70,9 +57,9 @@ Q_SIGNALS:
     void percentageChanged(int percentage);
 
 private:
-    explicit Battery(const QString &path, const QVariantMap &properties);
+    BLUEZQT_NO_EXPORT explicit Battery(const QString &path, const QVariantMap &properties);
 
-    class BatteryPrivate *const d;
+    std::unique_ptr<class BatteryPrivate> const d;
 
     friend class BatteryPrivate;
     friend class DevicePrivate;
